==> nvhpc-comm-libs-25.5-1-x86_64.pkg.tar.zst: opt/nvidia/hpc_sdk/Linux_x86_64/25.5/comm_libs/12.9/hpcx/hpcx-2.22.1/sharp/debug/share/locale/file_parser_lst.h <==
/*
 * SPDX-FileCopyrightText: NVIDIA CORPORATION & AFFILIATES
 * Copyright (c) 2024-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: LicenseRef-NvidiaProprietary
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#pragma once

#include "file_parser_fabric_abs.h"

class FileParserLst : public FileParserFabricAbs
{
    string m_roots_guid_file;
    string m_hc_coordinates_file;

    int ParseSubnetLinks();
    int ParseHyperCubeCoordinatesFile(MapGuidToHCCoordinates& coordinates_map);

   public:
    FileParserLst(const string& file_name,
                  TopologyType topology_type,
                  ExitOnError exit_on_error,
                  update_func_ptr update_start,
                  update_func_ptr update_end,
                  update_func_ptr update_failed,
                  CsvParser* csv_parser,
                  FabricGraph* fabric_graph,
                  const string& roots_guid_file,
                  const string& hc_coordinates_file)
        : FileParserFabricAbs(file_name, topology_type, exit_on_error, update_start, update_end, update_failed, csv_parser, fabric_graph),
          m_roots_guid_file(roots_guid_file),
          m_hc_coordinates_file(hc_coordinates_file)
    {}

    int Load();
};

==> nvhpc-comm-libs-25.11-1-x86_64.pkg.tar.zst: opt/nvidia/hpc_sdk/Linux_x86_64/25.11/comm_libs/13.0/hpcx/hpcx-2.25.1/sharp/debug/share/locale/file_parser_lst.h <==
/*
 * SPDX-FileCopyrightText: NVIDIA CORPORATION & AFFILIATES
 * Copyright (c) 2024-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: LicenseRef-NvidiaProprietary
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#pragma once

#include "file_parser_fabric_abs.h"

class FileParserLst : public FileParserFabricAbs
{
    string m_roots_guid_file;
    string m_hc_coordinates_file;

    int ParseSubnetLinks();
    int ParseHyperCubeCoordinatesFile(MapGuidToHCCoordinates& coordinates_map);

   public:
    FileParserLst(const string& file_name,
                  TopologyType topology_type,
                  ExitOnError exit_on_error,
                  update_func_ptr update_start,
                  update_func_ptr update_end,
                  update_func_ptr update_failed,
                  CsvParser* csv_parser,
                  FabricGraph* fabric_graph,
                  const string& roots_guid_file,
                  const string& hc_coordinates_file)
        : FileParserFabricAbs(file_name,
                              topology_type,
                              exit_on_error,
                              std::move(update_start),
                              std::move(update_end),
                              std::move(update_failed),
                              csv_parser,
                              fabric_graph),
          m_roots_guid_file(roots_guid_file),
          m_hc_coordinates_file(hc_coordinates_file)
    {}

    int Load() override;
};
